@@ -120,6 +120,7 @@ struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse, SDL_RWops*
         }
     }
     zsdl->ttf_iconv = iconv_open("UTF-8", "ISO8859-2");
+    if (zsdl->ttf_iconv == (iconv_t)-1) zinternal("Can't create TTF iconv object UTF-8 to ISO8859-2");
 
 #endif
     zsdl->pxformat = screen->format;
@@ -629,8 +630,10 @@ void zsdl_printf(SDL_Surface *surface, int x, int y, int color, int bgcolor, int
 
 		if (flags & ZFONT_UTF8){
 			if (zsdl->to8b_cd == NULL) zsdl->to8b_cd = iconv_open("iso-8859-2//TRANSLIT", "utf-8");
+            if (zsdl->to8b_cd == (iconv_t)-1) zinternal("Can't create iconv object iso-8859-2 to utf-8");
+
 			if (zsdl->to8b_gs == NULL) zsdl->to8b_gs = g_string_sized_new(strlen(s));
-			g_string_truncate(zsdl->to8b_gs, 0);
+            g_string_truncate(zsdl->to8b_gs, 0);
 			ziconv(zsdl->to8b_cd, s, zsdl->to8b_gs);
 			g_free(s);
 			s = g_strdup(zsdl->to8b_gs->str);
